@@ -39,7 +39,7 @@ has 'hints' => (
 has 'primitives' => (
     metaclass => 'Collection::Array',
     is => 'rw',
-    isa => 'ArrayRef[Geometry::Primitive]',
+    isa => 'ArrayRef',
     traits => [qw(Clone)],
     default => sub { [] },
     provides => {
